import javax.swing.*;
import java.awt.*;
import java.awt.event.*;

//=================================================
// L'exemple montre comment vous pourriez utiliser le manager layout: 
// GridBagLayout
//=================================================
public class fenetre3GBL {

   public static void main(String args[]){

      // Créer un objet de type frame, c'est la fenêtre affiché. 
      JFrame _fenetre = new JFrame("Convertisseur");

      // Fixer la Taille de la fenêtre. Paramètres: (pointX, pointY, largeur, hauteur)
     _fenetre.setBounds(200, 200, 350, 200);
      
      // Créer des composants 
      JLabel _lblTitre = new JLabel("Conversion euro => FF");
      JLabel _lblMont = new JLabel("Montant");
      JButton _btnConvertir = new JButton("Convertir");
      JButton _btnQuitter = new JButton("Quitter");
      JTextField _txtMontant = new JTextField(10);
      JTextField _txtResultat = new JTextField(20);
      _txtResultat.setEditable(false); // Composant utilisé pour montrer le résultat, par ça c'est pas modifiable
      
//=================================================
// IMPORTANT: Par défaut, le manager layout d'un frame est de type BorderLayout, c'est-à-dire, les composants pouvent être affichés en cinq places seulement: NORTH, SOUTH, CENTRE, WEST, EAST. Si vous avez besoin de changer ce manager layout par défaut, vous devez appeler la méthode "setLayout" de l'objet panel et donner par paramètre un objet Layout.
//=================================================
      // IMPORTANT: Je change le manager layout par défaut du frame à GridBagLayout. 
      _fenetre.setLayout(new GridBagLayout());

      // IMPORTANT: Je crée une contrainte
      GridBagConstraints constraint = new GridBagConstraints(); 

      // Les contraintes pour le label "Montant":
      // gridx = 0 : position X, c'est la colonne 0
      // gridy = 2 : position Y, c'est la ligne 2
      // weightx = 0.5 : apparence
      // insets(10, 10, 5, 10): espace supplémentaire autour du composant (top, left, bottom, right)
      // anchor = GridBagConstraints.EAST: Si le composant est plus petite que l'espace reservé, placer-le au EST
      constraint.gridx = 0;
      constraint.gridy = 2;
      constraint.weightx = 0.5;
      constraint.insets = new Insets(10, 10, 5, 10);
      constraint.anchor = GridBagConstraints.EAST;
      _fenetre.add(_lblMont, constraint); // Ajouter le composant et la contrainte

      // Les contraintes pour le textField pour taper le montant:
      // gridx = 1 : position X, c'est colonne 1
      // gridy = 2 : position Y, c'est ligne 2
      // weightx = 0.5 : apparence
      // insets(10, 10, 5, 10) : espace supplémentaire autour du composant (top, left, bottom, right)
      // anchor = GridBagConstraints.WEST : Si le composant est plus petite que l'espace reservé, placer-le au OUEST
      // fill =  GridBagConstraints.HORIZONTAL : le composant occupera tout l'espace horizontal
      constraint.gridx = 1;
      constraint.gridy = 2;
      constraint.anchor = GridBagConstraints.WEST;
      constraint.fill = GridBagConstraints.HORIZONTAL;
      _fenetre.add(_txtMontant, constraint);

      // Les contraintes pour le button "Convertir":
      // gridx = 0 : position X, c'est colonne 0
      // gridy = 3 : position Y, c'est ligne 3
      // weightx = 0.5 : apparence
      // insets(5, 10, 10, 10) : espace supplémentaire autour du composant (top, left, bottom, right)
      // anchor = GridBagConstraints.EAST : Si le composant est plus petite que l'espace reservé, placer-le au EST
      // fill =  GridBagConstraints.NONE : le composant n'occupera pas tout l'espace ni horizontalment ni verticalement
      //ipady = 10 : ajoute 10 pixels à la hauteur du composant
      constraint.gridx = 0;
      constraint.gridy = 3;
      constraint.insets = new Insets(5,10,10,10);
      constraint.anchor = GridBagConstraints.EAST;
      constraint.fill = GridBagConstraints.NONE;
      constraint.ipady = 10;
      _fenetre.add(_btnConvertir, constraint);

      // Les contraintes pour le button "Quitter":
      // gridx = 1 : position X, c'est colonne 1
      // gridy = 3 : position Y, c'est ligne 3
      // weightx = 0.5 : apparence
      // insets(5, 10, 10, 10) : espace supplémentaire autour du composant (top, left, bottom, right)
      // anchor = GridBagConstraints.WEST : Si le composant est plus petite que l'espace reservé, placer-le au OUEST
      // fill =  GridBagConstraints.NONE : le composant n'occupera pas tout l'espace ni horizontalment ni verticalement
      //ipady = 10 : ajoute 10 pixels à la hauteur du composant
      constraint.gridx = 1;
      constraint.gridy = 3;
      constraint.anchor = GridBagConstraints.WEST;
      constraint.fill = GridBagConstraints.NONE;
      _fenetre.add(_btnQuitter, constraint);

      // Les contraintes pour le textField pour afficher le résultat:
      // gridx = 0 : position X, c'est colonne 0
      // gridy = 4 : position Y, c'est ligne 4
      // gridwidth = 2 : le composant occupe deux colonnes
      // weightx = 1 : apparence
      // weighty = 0.5: apparence
      // insets(5, 5, 5, 5) : espace supplémentaire autour du composant (top, left, bottom, right)
      // anchor = GridBagConstraints.PAGE_END : Si le composant est plus petite que l'espace reservé, placer-le à la fin de la fenêtre
      // fill =  GridBagConstraints.VERTICAL : le composant occupera tout l'espace verticale
      // ipadx = 60 : ajoute 60 pixels à la largueur du composant
      // ipady = 0 : ajoute 0 pixels à la hauteur du composant
      constraint.gridx = 0;
      constraint.gridy = 4;
      constraint.gridwidth = 2;
      constraint.weightx = 1;
      constraint.weighty = 0.5;
      constraint.insets = new Insets(5,5,5,5);
      constraint.anchor = GridBagConstraints.PAGE_END;
      constraint.fill = GridBagConstraints.VERTICAL;
      constraint.ipadx = 60;
      constraint.ipady = 0;
      _fenetre.add(_txtResultat, constraint);

//=================================================
// IMPORTANT: Si la première ligne doit occuper plusiers cases de la grille, il faut que ajuoter-le à la fin du code pour éviter problèmes de visualisation
//=================================================
      // Les contraintes pour le label "Conversion euro => FF":
      // gridx = 0 : position X, c'est colonne 0
      // gridy = 0 : position Y, c'est ligne 0
      // gridwidth = 2 : le composant occupe deux colonnes
      // gridheight = 2 : le composant occupe deux lignes
      // weightx = 0.5 : apparence
      // weighty = 0.5: apparence
      // insets(0, 0, 0, 0) : reset
      // anchor = GridBagConstraints.CENTER : Si le composant est plus petite que l'espace reservé, placer-le au centre de la fenêtre
      // fill =  GridBagConstraints.NON : reset
      // ipadx = 0 : reset
      // ipady = 0 : reset
      constraint.gridx = 0;
      constraint.gridy = 0;
      constraint.gridwidth = 2;
      constraint.gridheight = 2;
      constraint.weightx = 0.5;
      constraint.weighty = 0.5;
      constraint.insets = new Insets(0,0,0,0);
      constraint.anchor = GridBagConstraints.CENTER;
      constraint.fill = GridBagConstraints.NONE;
      constraint.ipadx = 0;
      constraint.ipady = 0;

      _fenetre.add(_lblTitre, constraint);


      // La méthode "pack" redimensionne la taille de la fenêtre que vous avez donné (setBounds ou setSize), à ajuster la fenêtre à une taille juste pour les composants
      //_fenetre.pack();

//=================================================
// IMPORTANT: Si vous avez regarde bien, quand je ferme la fenêtre le programme continue à marcher. Il faut appeler "setDefaultCloseOperation" pour indiquer que chaque fois que je ferme la fenêtre le programme dois arrêter.
//=================================================
      _fenetre.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

      // J'affiche la fenêtre. La méthode "setVisible" remplace la méthode "show" (méthode obsolète)
      _fenetre.setVisible(true); // _fenetre.show();
      
    }

}
